@@ -1,5 +1,6 @@
 import logging
 import time
+from datetime import date
 from itertools import batched, chain
 from pathlib import Path
 from typing import (
@@ -15,7 +16,6 @@ from typing import (
 )
 
 import pandas as pd
-from bearish.interface.interface import BearishDbBase  # type: ignore
 from bearish.models.assets.equity import BaseEquity  # type: ignore
 from bearish.models.base import (  # type: ignore
     DataSourceBase,
@@ -87,10 +87,10 @@ def _compute_growth(series: pd.Series) -> bool:
     return all(series.pct_change(fill_method=None).dropna() > 0)
 
 
-def _all_positive(series: pd.Series) -> bool:
+def _all_positive(series: pd.Series, threshold: int = 0) -> bool:
     if series.empty:
         return False
-    return all(series.dropna() > 0)
+    return all(series.dropna() > threshold)
 
 
 def _get_last(data: pd.Series) -> Optional[float]:
@@ -274,7 +274,7 @@ class BaseFundamentalAnalysis(BaseModel):
             debt_to_equity = (
                 balance_sheet.total_liabilities / balance_sheet.total_shareholder_equity
             ).dropna()
-            positive_debt_to_equity = _all_positive(debt_to_equity)
+            positive_debt_to_equity = _all_positive(debt_to_equity, threshold=1)
 
             # Add relevant balance sheet data to financials
             financial["total_shareholder_equity"] = balance_sheet[
@@ -433,6 +433,10 @@ class FundamentalAnalysis(YearlyFundamentalAnalysis, QuarterlyFundamentalAnalysi
         ]
 
 
+class AnalysisEarningsDate(BaseModel):
+    next_earnings_date: Optional[date] = None
+
+
 class AnalysisView(BaseModel):
     sector: Annotated[
         Optional[str],
@@ -484,15 +488,15 @@ class AnalysisView(BaseModel):
             default=None,
         ),
     ]
-    median_yearly_growth: Optional[float] = None
-    median_weekly_growth: Optional[float] = None
-    median_monthly_growth: Optional[float] = None
+    yearly_growth: Optional[float] = None
+    weekly_growth: Optional[float] = None
+    monthly_growth: Optional[float] = None
 
 
-class Analysis(AnalysisView, BaseEquity, TechnicalAnalysis, FundamentalAnalysis):  # type: ignore
+class Analysis(AnalysisEarningsDate, AnalysisView, BaseEquity, TechnicalAnalysis, FundamentalAnalysis):  # type: ignore
 
     @classmethod
-    def from_ticker(cls, bearish_db: BearishDbBase, ticker: Ticker) -> "Analysis":
+    def from_ticker(cls, bearish_db: "BullishDb", ticker: Ticker) -> "Analysis":
         asset = bearish_db.read_assets(
             AssetQuery(
                 symbols=Symbols(equities=[ticker]),
@@ -504,11 +508,13 @@ class Analysis(AnalysisView, BaseEquity, TechnicalAnalysis, FundamentalAnalysis)
         fundamental_analysis = FundamentalAnalysis.from_financials(financials, ticker)
         prices = Prices.from_ticker(bearish_db, ticker)
         technical_analysis = TechnicalAnalysis.from_data(prices.to_dataframe(), ticker)
+        next_earnings_date = bearish_db.read_next_earnings_date(ticker.symbol)
         return cls.model_validate(
             equity.model_dump()
             | fundamental_analysis.model_dump()
             | technical_analysis.model_dump()
             | {
+                "next_earnings_date": next_earnings_date,
                 "price_per_earning_ratio": (
                     (
                         technical_analysis.last_price
@@ -518,7 +524,7 @@ class Analysis(AnalysisView, BaseEquity, TechnicalAnalysis, FundamentalAnalysis)
                     and fundamental_analysis.earning_per_share != 0
                     and fundamental_analysis.earning_per_share is not None
                     else None
-                )
+                ),
             }
         )
 
